@@ -3,22 +3,19 @@ import csv
 import glob
 import logging
 import shutil
-import sys
 import time
 import traceback
 
-import six
-
-from certbot._internal import constants
 from certbot import errors
 from certbot import util
-from certbot.compat import os
+from certbot._internal import constants
 from certbot.compat import filesystem
+from certbot.compat import os
 
 logger = logging.getLogger(__name__)
 
 
-class Reverter(object):
+class Reverter:
     """Reverter Class - save and revert configuration checkpoints.
 
     This class can be used by the plugins, especially Installers, to
@@ -180,7 +177,7 @@ class Reverter(object):
                     shutil.copy2(filename, os.path.join(
                         cp_dir, os.path.basename(filename) + "_" + str(idx)))
                     op_fd.write('{0}\n'.format(filename))
-                # http://stackoverflow.com/questions/4726260/effective-use-of-python-shutil-copy2
+                # https://stackoverflow.com/questions/4726260/effective-use-of-python-shutil-copy2
                 except IOError:
                     op_fd.close()
                     logger.error(
@@ -195,7 +192,7 @@ class Reverter(object):
         with open(os.path.join(cp_dir, "CHANGES_SINCE"), "a") as notes_fd:
             notes_fd.write(save_notes)
 
-    def _read_and_append(self, filepath):  # pylint: disable=no-self-use
+    def _read_and_append(self, filepath):
         """Reads the file lines and returns a file obj.
 
         Read the file returning the lines, and a pointer to the end of the file.
@@ -250,13 +247,12 @@ class Reverter(object):
             raise errors.ReverterError(
                 "Unable to remove directory: %s" % cp_dir)
 
-    def _run_undo_commands(self, filepath):  # pylint: disable=no-self-use
+    def _run_undo_commands(self, filepath):
         """Run all commands in a file."""
-        # NOTE: csv module uses native strings. That is, bytes on Python 2 and
-        # unicode on Python 3
+        # NOTE: csv module uses native strings. That is unicode on Python 3
         # It is strongly advised to set newline = '' on Python 3 with CSV,
         # and it fixes problems on Windows.
-        kwargs = {'newline': ''} if sys.version_info[0] > 2 else {}
+        kwargs = {'newline': ''}
         with open(filepath, 'r', **kwargs) as csvfile:  # type: ignore
             csvreader = csv.reader(csvfile)
             for command in reversed(list(csvreader)):
@@ -355,7 +351,7 @@ class Reverter(object):
         command_file = None
         # It is strongly advised to set newline = '' on Python 3 with CSV,
         # and it fixes problems on Windows.
-        kwargs = {'newline': ''} if sys.version_info[0] > 2 else {}
+        kwargs = {'newline': ''}
         try:
             if os.path.isfile(commands_fp):
                 command_file = open(commands_fp, "a", **kwargs)  # type: ignore
@@ -413,7 +409,7 @@ class Reverter(object):
                     "Incomplete or failed recovery for IN_PROGRESS checkpoint "
                     "- %s" % self.config.in_progress_dir)
 
-    def _remove_contained_files(self, file_list):  # pylint: disable=no-self-use
+    def _remove_contained_files(self, file_list):
         """Erase all files contained within file_list.
 
         :param str file_list: file containing list of file paths to be deleted
@@ -518,7 +514,7 @@ class Reverter(object):
         # It is possible save checkpoints faster than 1 per second resulting in
         # collisions in the naming convention.
 
-        for _ in six.moves.range(2):
+        for _ in range(2):
             timestamp = self._checkpoint_timestamp()
             final_dir = os.path.join(self.config.backup_dir, timestamp)
             try:
